@@ -3,6 +3,12 @@ from .binning import ontime_binning, qla_binning, groupby_observation_blocks, bi
 
 from .core import calc_run_summary_source_independent, split_on_off_source_independent
 
+from .source import (
+    calc_theta_equatorial,
+    calc_theta_camera,
+    calc_theta_offs_camera,
+)
+
 
 __all__ = [
     'li_ma_significance',
@@ -12,4 +18,7 @@ __all__ = [
     'bin_runs',
     'calc_run_summary_source_independent',
     'split_on_off_source_independent',
+    'calc_theta_equatorial',
+    'calc_theta_camera',
+    'calc_theta_offs_camera',
 ]
